# ComicWalkerDownloader aka cowado

![PyPI - Version](https://img.shields.io/pypi/v/cowado?color=blue&link=https%3A%2F%2Fpypi.org%2Fproject%2Fcowado%2F)
![Static Badge](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%203.12-blue?link=https%3A%2F%2Fwww.python.org%2Fdownloads%2F)
[![PyPI Downloads](https://static.pepy.tech/badge/cowado)](https://pepy.tech/projects/cowado)

CLI tool to download manga from ComicWalker.

## Requirements

**Python 3.7+** must be installed on your system. You can download it from [python.org](https://www.python.org/downloads/).

## Installation

```bash
pip install cowado
```

Or from source:

```bash
git clone https://github.com/Timolio/ComicWalkerDownloader.git
cd ComicWalkerDownloader
pip install .
```

## Usage

Navigate to the folder where you want the images to be saved, then run:

```bash
cowado [comicwalker_url]
```

Example:

```bash
cowado https://comic-walker.com/detail/KC_006351_S/episodes/KC_0063510000500011_E?episodeType=latest
```

## Notes

Make sure you do not use this tool to infringe any copyright laws.
